==> nextcloud-app-bookmarks-1:15.1.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/lv.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Grāmatzīmes",
    "You bookmarked \"%s\"" : "Tu pievienoji \"%s\" grāmatzīmēm",
    "No file provided for import" : "Nav norādīta importējamā datne",
    "Bookmark" : "Grāmatzīme",
    "Details" : "Detaļas",
    "Rename" : "Pārdēvēt",
    "Copy link" : "Kopēt saiti",
    "Move" : "Pārvietot",
    "Select all" : "Atzīmēt visu",
    "Go back" : "Atpakaļ",
    "New" : "Jauns",
    "New folder" : "Jauna mape",
    "Search" : "Meklēt",
    "Empty trash bin" : "Iztīrīt atkritni",
    "_%n folder_::_%n folders_" : ["%n mapes","%n mape","%n mapes"],
    "Add a bookmark" : "Pievienot grāmatzīmi",
    "Rename folder" : "Pārdēvēt mapi",
    "Choose folder" : "Izvēlēties mapi",
    "Submit" : "Iesniegt",
    "Cancel" : "Atcelt",
    "Recent" : "Nesenās",
    "Shared with you" : "Koplietots ar jums",
    "Files" : "Datnes",
    "Delete" : "Dzēst",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Grāmatzīmju lietotne var automātiski arhivēt saglabāto saišu tīmekļa saturu",
    "Bookmarklet" : "Grāmatzīme",
    "Need help?" : "Vajadzīga palīdzība?",
    "Title" : "Amats",
    "Link" : "Saite",
    "Tags" : "Birkas",
    "Notes" : "Piezīmes",
    "Notes for this bookmark …" : "Šīs grāmatzīmes piezīmes …",
    "Download file" : "Lejupielādēt datni",
    "Link copied" : "Saite nokopēta",
    "Owner" : "Īpašnieks",
    "Sharing" : "Koplietošana",
    "Share link" : "Koplietot saiti",
    "Create public link" : "Izveidot publisku saiti",
    "Allow editing" : "Atļaut labošanu",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Failed to save settings" : "Neizdevās saglabāt iestatījumus",
    "Failed to load settings" : "Neizdevās ielādēt iestatījumus",
    "Privacy" : "Privātums",
    "Previews" : "Priekšskatījumi",
    "Screeenly API URL" : "Screeenly API saite",
    "Screeenly API key" : "Screeenly API atslēga",
    "This URL is already bookmarked! Overwrite?" : "Šī saite jau ir grāmatzīmēs! Vai pārrakstīt?",
    "Folder" : "Mape",
    "Save" : "Saglabāt",
    "What's new?" : "Kas jauns?",
    "Failed to delete bookmark" : "Neizdevās izdzēst grāmatzīmi",
    "Failed to rename tag" : "Neizdevās pārdēvēt birku",
    "Failed to load deleted folders" : "Neizdevās ielādēt izdzēstās mapes",
    "Failed to load deleted bookmarks" : "Neizdevās ielādēt izdzēstās grāmatzīmes",
    "Failed to delete folder" : "Neizdevās izdzēst mapi",
    "Failed to delete share {shareId}" : "Neizdevās izdzēst koplietojumu {shareId}",
    "Create bookmarks for mentioned links" : "Izveidot grāmatzīmes pieminētajām saitēm",
    "Bookmarks feed" : "Grāmatzīmju plūsma"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-app-bookmarks-1:15.2.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/lv.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Grāmatzīmes",
    "You bookmarked \"%s\"" : "Tu pievienoji \"%s\" grāmatzīmēm",
    "You created folder \"%s\"" : "Tu izveidoji mapi \"%s\"",
    "No file provided for import" : "Ievietošanai nav norādīta neviena datne",
    "Bookmark" : "Grāmatzīme",
    "Details" : "Informācija",
    "Rename" : "Pārdēvēt",
    "Copy link" : "Ievietot saiti starpliktuvē",
    "Move" : "Pārvietot",
    "Select all" : "Atzīmēt visu",
    "Sort by last modified" : "Kārtot pēc pēdējās izmainīšanas",
    "Go back" : "Atpakaļ",
    "New" : "Jauns",
    "New folder" : "Jauna mape",
    "Search" : "Meklēt",
    "Empty trash bin" : "Iztīrīt atkritni",
    "_%n folder_::_%n folders_" : ["%n mapes","%n mape","%n mapes"],
    "Add a bookmark" : "Pievienot grāmatzīmi",
    "Rename folder" : "Pārdēvēt mapi",
    "Choose folder" : "Izvēlēties mapi",
    "Submit" : "Iesniegt",
    "Cancel" : "Atcelt",
    "Recent" : "Nesenās",
    "Shared with you" : "Koplietots ar jums",
    "Files" : "Datnes",
    "Delete" : "Dzēst",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Grāmatzīmju lietotne var automātiski arhivēt saglabāto saišu tīmekļa saturu",
    "Bookmarklet" : "Grāmatzīme",
    "Need help?" : "Vajadzīga palīdzība?",
    "Title" : "Amats",
    "Link" : "Saite",
    "Tags" : "Birkas",
    "Notes" : "Piezīmes",
    "Notes for this bookmark …" : "Šīs grāmatzīmes piezīmes …",
    "Download file" : "Lejupielādēt datni",
    "Link copied" : "Saite nokopēta",
    "Owner" : "Īpašnieks",
    "Sharing" : "Koplietošana",
    "Share link" : "Koplietot saiti",
    "Create public link" : "Izveidot publisku saiti",
    "Allow editing" : "Atļaut labošanu",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Failed to save settings" : "Neizdevās saglabāt iestatījumus",
    "Failed to load settings" : "Neizdevās ielādēt iestatījumus",
    "Privacy" : "Privātums",
    "Previews" : "Priekšskatījumi",
    "Screeenly API URL" : "Screeenly API saite",
    "Screeenly API key" : "Screeenly API atslēga",
    "This URL is already bookmarked! Overwrite?" : "Šī saite jau ir grāmatzīmēs! Vai pārrakstīt?",
    "Folder" : "Mape",
    "Save" : "Saglabāt",
    "What's new?" : "Kas jauns?",
    "Failed to delete bookmark" : "Neizdevās izdzēst grāmatzīmi",
    "Failed to rename tag" : "Neizdevās pārdēvēt birku",
    "Failed to load deleted folders" : "Neizdevās ielādēt izdzēstās mapes",
    "Failed to load deleted bookmarks" : "Neizdevās ielādēt izdzēstās grāmatzīmes",
    "Failed to delete folder" : "Neizdevās izdzēst mapi",
    "Failed to delete share {shareId}" : "Neizdevās izdzēst koplietojumu {shareId}",
    "Create bookmarks for mentioned links" : "Izveidot grāmatzīmes pieminētajām saitēm",
    "Bookmarks feed" : "Grāmatzīmju plūsma"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
